/* Enter one or more SQL statements separated by semicolons */



create table xpto538017.Carg (
	
	Codigo_carg char(3) not null,	
	Nome_carg char(35) not null,
	Classe_carg char(1) Default 'P' not null,
	Tipo_contrato_carg char(1) Default 'H' not null,
	Salario_piso_carg dec(7,2),
	Salario_teto_carg dec(7,2),
	Ind_comissao_carg char(1) Default 'N' not null,
	Constraint xpto538017.PK_Carg primary key(Codigo_carg),
	Constraint xpto538017.UK_Nome_carg Unique(Nome_carg),	
	Constraint xpto538017.CK_Classe_carg Check(Classe_carg in('G','P','T')),
	Constraint xpto538017.CK_Tipo_contrato_carg Check(Tipo_contrato_carg in('H','M','R','S')),
	Constraint xpto538017.CK_Ind_comissao_carg Check(Ind_comissao_carg in('N','S')),
	Constraint xpto538017.CK_Nome_carg Check(Nome_carg <> ' '),
	Constraint xpto538017.CK_Salario_piso_carg Check(Salario_piso_carg > 0 and salario_piso_carg < salario_teto_carg),
	Constraint xpto538017.CK_Salario_teto_carg Check(Salario_teto_carg > 0)
);



create table xpto538017.Func (
	Numero_func smallint not null,
	Nome_func char(40) not null, 
	CPF_func numeric(11,0) not null,	
	Data_admissao_func date Default current_date not null,
	Data_saida_func date,
	Situacao_func char(1) Default 'A' not null,
	Codigo_carg char(3),
	Salario_base_func dec(7,2),
	Constraint xpto538017.PK_Func primary key(Numero_func),
	Constraint xpto538017.FK_Func foreign key(Codigo_carg) References xpto538017.Carg on delete restrict,
	Constraint xpto538017.UK_cpf_func unique(cpf_func),
	Constraint xpto538017.CK_Situacao_func Check(Situacao_func in('A','I','L','M','P')),	
	Constraint xpto538017.CK_Nome_func Check(Nome_func <> ' '),	
	Constraint xpto538017.CK_Data_saida_func Check(Data_saida_func  >=  Data_admissao_func),
	Constraint xpto538017.CK_Salario_base_func Check(Salario_base_func > 0) 
);


create table xpto538017.Dpto (
	Codigo_dpto char (3) not null,
	Nome_dpto char(30) not null,
	Numero_gerente smallint not null,
	Constraint xpto538017.PK_codigo_dpto primary key(Codigo_dpto),
	Constraint xpto538017.FK_dpto foreign key (Numero_gerente) References 	xpto538017.Func(Numero_func)  on delete  restrict,
	Constraint xpto538017.CK_Nome_dpto Check(Nome_dpto <> ' '),
	Constraint xpto538017.UK_Nome_dpto Unique(Nome_dpto)
);



create table xpto538017.Pgto (
	Ano_ref_pgto numeric(4,0) not null,
	Mes_ref_pgto numeric(2,0) not null,
	Numero_func smallint not null,
	Sal_base_pgto dec(7,2) not null,	
	Total_desc_pgto dec(7,2),
	Total_horas_pgto dec(3,0),
	Constraint xpto538017.PK_ano_ref_pgto_ref_pgto_numero_func primary key(Ano_ref_pgto, Mes_ref_pgto, Numero_func),
	Constraint xpto538017.FK_Pgto foreign key (Numero_func) References xpto538017.Func on delete cascade,
	Constraint xpto538017.CK_Mes_ref_pgto Check(Mes_ref_pgto >= 1 and Mes_ref_pgto <= 13), 
	Constraint xpto538017.CK_Sal_base_pgto Check(Sal_base_pgto >= 0), 
	Constraint xpto538017.CK_Total_desc_pgto Check(Total_desc_pgto >= 0),
	Constraint xpto538017.CK_Total_horas_pgto Check(Total_horas_pgto >= 0)
);



create table xpto538017.Hist (
	Numero_hist smallint not null,
	Numero_func smallint not null,
	Data_ini_hist date,
	Codigo_carg char(3) not null,
	Salario_base_func dec(7,2),
	Constraint xpto538017.PK_numero_hist_numero_func primary key(Numero_hist, Numero_func),
	Constraint xpto538017.FK_Hist_func  foreign key (Numero_func) References xpto538017.Func on delete cascade,
	Constraint xpto538017.FK_Hist_carg  foreign key (Codigo_carg) References xpto538017.Carg on delete cascade
);



create table xpto538017.Aloc (
	Codigo_dpto char (3) not null,
	Numero_func smallint not null,
	Constraint xpto538017.PK_codigo_dpto_numero_func primary key(Codigo_dpto, Numero_func),
	Constraint xpto538017.FK_Aloc_dpto foreign key (Codigo_dpto) References xpto538017.Dpto on delete cascade,
	Constraint xpto538017.FK_Aloc_func foreign key (Numero_func) References xpto538017.Func on delete cascade
);













	
